==> mono_1.2.2.1.orig.tar.gz: mono-1.2.2.1/mcs/class/Microsoft.Build.Tasks/Microsoft.Build.Tasks.Deployment.Bootstrapper/BootstrapperBuilder.cs <==
//
// BootstrapperBuilder.cs
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
//
// (C) 2006 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#if NET_2_0

using System;
using System.Runtime.InteropServices;
using Microsoft.Build.Framework;

namespace Microsoft.Build.Tasks.Deployment.Bootstrapper {

	[ClassInterface (ClassInterfaceType.None)]
	[Guid ("1D9FE38A-0226-4b95-9C6B-6DFFA2236270")]
	[ComVisible (true)]
	public class BootstrapperBuilder : IBootstrapperBuilder {
		
		string	path;
		ProductCollection	products;

		public BootstrapperBuilder ()
		{
		}
		
		public string Path {
			get { return path; }
			set { path = value; }
		}
		
		public ProductCollection Products {
			get { return products; }
		}
		
		[MonoTODO]
		public BuildResults Build (BuildSettings settings)
		{
			throw new NotImplementedException ();
		}
		
		[MonoTODO]
		public string[] GetOutputFolders (string[] productCodes, string culture, string fallbackCulture)
		{
			throw new NotImplementedException ();
		}
	}
}

#endif

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/Microsoft.Build.Tasks/Microsoft.Build.Tasks.Deployment.Bootstrapper/BootstrapperBuilder.cs <==
//
// BootstrapperBuilder.cs
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
//
// (C) 2006 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#if NET_2_0

using System;
using System.Runtime.InteropServices;
using Microsoft.Build.Framework;

namespace Microsoft.Build.Tasks.Deployment.Bootstrapper {

	[ClassInterface (ClassInterfaceType.None)]
	[Guid ("1D9FE38A-0226-4b95-9C6B-6DFFA2236270")]
	[ComVisible (true)]
	public class BootstrapperBuilder : IBootstrapperBuilder {
		
		string			path;
		ProductCollection	products;

		public BootstrapperBuilder ()
		{
		}
		
		[MonoTODO]
		public BuildResults Build (BuildSettings settings)
		{
			throw new NotImplementedException ();
		}
		
		[MonoTODO]
		public string [] GetOutputFolders (string [] productCodes, string culture, string fallbackCulture,
						   ComponentsLocation componentsLocation)
		{
			throw new NotImplementedException ();
		}

		public string Path {
			get { return path; }
			set { path = value; }
		}
		
		public ProductCollection Products {
			get { return products; }
		}
	}
}

#endif
